@@ -16,6 +16,5 @@ def check_result(result_dict: dict, result_check_dict: dict):
                     right_value=value, wrong_value=result_dict.get(key)
                 ), file=sys.stderr
             )
-            return "value should be {right_value} but value was {wrong_value}".format(right_value=value,
-                                                                                      wrong_value=result_dict.get(key))
-    return True
+            raise APIAssertException("value should be {right_value} but value was {wrong_value}".format(right_value=value,
+                                                                                      wrong_value=result_dict.get(key)))
